==> vdr-1.6.0-micky979.tar.bz2: vdr-1.6.0-micky979/PLUGINS/src/menuorg-0.4/src/OsdItemDefinition.cpp <==
/*
 * vdr-menuorg - A plugin for the Linux Video Disk Recorder
 * Copyright (c) 2007 - 2008 Tobias Grimm <vdr@e-tobi.net>
 * Copyright (c) 2007        Thomas Creutz <thomas.creutz@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * $Id: OsdItemDefinition.cpp 6965 2008-03-22 19:52:34Z svntobi $
 *
 */

#include "OsdItemDefinition.h"

OsdItemDefinition::OsdItemDefinition(cOsdItem* osdItem, bool isSelected)
{
    _osdItem = osdItem;
    _isSelected = isSelected;
}

bool OsdItemDefinition::IsCustomOsdItem()
{
    return true;
}

bool OsdItemDefinition::IsPluginItem()
{
    return false;
}

cOsdItem* OsdItemDefinition::CustomOsdItem()
{
    return _osdItem; 
}

const char* OsdItemDefinition::PluginMenuEntry()
{
    return NULL;
}

bool OsdItemDefinition::IsSelected()
{
    return _isSelected;
}

int OsdItemDefinition::PluginIndex()
{
    return 0;
}

==> vdr-1.6.0-2-micky979.tar.bz2: vdr-1.6.0-2-micky979/PLUGINS/src/menuorg-0.4.4/src/OsdItemDefinition.cpp <==
/*
 * vdr-menuorg - A plugin for the Linux Video Disk Recorder
 * Copyright (c) 2007 - 2008 Tobias Grimm <vdr@e-tobi.net>
 * Copyright (c) 2007        Thomas Creutz <thomas.creutz@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * $Id: OsdItemDefinition.cpp 7083 2008-03-24 22:32:17Z svntobi $
 *
 */

#include "OsdItemDefinition.h"

OsdItemDefinition::OsdItemDefinition(MenuNode* menuNode, cOsdItem* osdItem, bool isSelected)
    :MenuItemDefinition(menuNode)
{
    _osdItem = osdItem;
    _isSelected = isSelected;
}

bool OsdItemDefinition::IsCustomOsdItem()
{
    return true;
}

bool OsdItemDefinition::IsPluginItem()
{
    return false;
}

cOsdItem* OsdItemDefinition::CustomOsdItem()
{
    return _osdItem; 
}

const char* OsdItemDefinition::PluginMenuEntry()
{
    return NULL;
}

bool OsdItemDefinition::IsSelected()
{
    return _isSelected;
}

int OsdItemDefinition::PluginIndex()
{
    return 0;
}
